@@ -39,10 +39,11 @@ globalVariables(c('..density..', 'Cairo' ,'aes', 'dplyr' ,'element_blank', 'elem
 
 rcssci_cox<-function(data,knot,y,x,time,covs,prob,filepath,...)
 {
-  rcs_cox.prob(data= data, knot=knot,y = y,x = x,covs=covs,time =time, prob=, filepath=filepath)
-  rcs_cox.ushap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=, filepath=filepath)
-  rcs_cox.nshap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=, filepath=filepath)
-  rcs_cox.lshap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=, filepath=filepath)
+  if (!missing(knot)) {warning("please be sure of knot by AIC min(default) or preliminary investigation suggested")}
+  rcs_cox.prob(data= data, knot=knot,y = y,x = x,covs=covs,time =time, prob=prob, filepath=filepath)
+  rcs_cox.ushap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=prob, filepath=filepath)
+  rcs_cox.nshap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=prob, filepath=filepath)
+  rcs_cox.lshap(data= data,knot=knot,y = y,x = x,covs=covs,time =time, prob=prob, filepath=filepath)
 }
 
 
