@@ -38,10 +38,11 @@ globalVariables(c('..density..', 'Cairo' ,'aes', 'dplyr' ,'element_blank', 'elem
 
 rcssci_logistic<-function(data,knot,y,x,covs,prob,filepath,...)
 {
-  rcs_logistic.prob(data= data, knot=knot,y = y,x = x,covs=covs,prob=, filepath=filepath)
-  rcs_logistic.ushap(data= data,knot=knot,y = y,x = x,covs=covs,prob=, filepath=filepath)
-  rcs_logistic.nshap(data= data,knot=knot,y = y,x = x,covs=covs,prob=, filepath=filepath)
-  rcs_logistic.lshap(data= data,knot=knot,y = y,x = x,covs=covs,prob=, filepath=filepath)
+  if (!missing(knot)) {warning("please be sure of knot by AIC min(default) or preliminary investigation suggested")}
+  rcs_logistic.prob(data= data, knot=knot,y = y,x = x,covs=covs,prob=prob, filepath=filepath)
+  rcs_logistic.ushap(data= data,knot=knot,y = y,x = x,covs=covs,prob=prob, filepath=filepath)
+  rcs_logistic.nshap(data= data,knot=knot,y = y,x = x,covs=covs,prob=prob, filepath=filepath)
+  rcs_logistic.lshap(data= data,knot=knot,y = y,x = x,covs=covs,prob=prob, filepath=filepath)
 }
 
 
